==> ansible-9.3.0.tgz: lib/python3.10/site-packages/ansible_collections/fortinet/fortimanager/plugins/modules/fmgr_firewall_explicitproxyaddress.py <==
#!/usr/bin/python
from __future__ import absolute_import, division, print_function
# Copyright 2019-2024 Fortinet, Inc.
# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

__metaclass__ = type

ANSIBLE_METADATA = {'status': ['preview'],
                    'supported_by': 'community',
                    'metadata_version': '1.1'}

DOCUMENTATION = '''
---
module: fmgr_firewall_explicitproxyaddress
short_description: Explicit web proxy address configuration.
description:
    - This module is able to configure a FortiManager device.
    - Examples include all parameters and values which need to be adjusted to data sources before usage.

version_added: "2.2.0"
author:
    - Xinwei Du (@dux-fortinet)
    - Xing Li (@lix-fortinet)
    - Jie Xue (@JieX19)
    - Link Zheng (@chillancezen)
    - Frank Shen (@fshen01)
    - Hongbin Lu (@fgtdev-hblu)
notes:
    - Starting in version 2.4.0, all input arguments are named using the underscore naming convention (snake_case).
      Please change the arguments such as "var-name" to "var_name".
      Old argument names are still available yet you will receive deprecation warnings.
      You can ignore this warning by setting deprecation_warnings=False in ansible.cfg.
    - Running in workspace locking mode is supported in this FortiManager module, the top
      level parameters workspace_locking_adom and workspace_locking_timeout help do the work.
    - To create or update an object, use state present directive.
    - To delete an object, use state absent directive.
    - Normally, running one module can fail when a non-zero rc is returned. you can also override
      the conditions to fail or succeed with parameters rc_failed and rc_succeeded
options:
    access_token:
        description: The token to access FortiManager without using username and password.
        type: str
    bypass_validation:
        description: Only set to True when module schema diffs with FortiManager API structure, module continues to execute without validating parameters.
        type: bool
        default: false
    enable_log:
        description: Enable/Disable logging for task.
        type: bool
        default: false
    forticloud_access_token:
        description: Authenticate Ansible client with forticloud API access token.
        type: str
    proposed_method:
        description: The overridden method for the underlying Json RPC request.
        type: str
        choices:
          - update
          - set
          - add
    rc_succeeded:
        description: The rc codes list with which the conditions to succeed will be overriden.
        type: list
        elements: int
    rc_failed:
        description: The rc codes list with which the conditions to fail will be overriden.
        type: list
        elements: int
    state:
        description: The directive to create, update or delete an object.
        type: str
        required: true
        choices:
          - present
          - absent
    workspace_locking_adom:
        description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
        type: str
    workspace_locking_timeout:
        description: The maximum time in seconds to wait for other user to release the workspace lock.
        type: int
        default: 300
    adom:
        description: The parameter (adom) in requested url.
        type: str
        required: true
    firewall_explicitproxyaddress:
        description: The top level parameters set.
        required: false
        type: dict
        suboptions:
            case-sensitivity:
                type: str
                description: Deprecated, please rename it to case_sensitivity. Case sensitivity in pattern.
                choices:
                    - 'disable'
                    - 'enable'
            category:
                type: str
                description: FortiGuard category ID.
            color:
                type: int
                description: GUI icon color.
            comment:
                type: str
                description: Comment.
            header:
                type: str
                description: HTTP header regular expression.
            header-group:
                type: list
                elements: dict
                description: Deprecated, please rename it to header_group.
                suboptions:
                    case-sensitivity:
                        type: str
                        description: Deprecated, please rename it to case_sensitivity. Case sensitivity in pattern.
                        choices:
                            - 'disable'
                            - 'enable'
                    header:
                        type: str
                        description: HTTP header regular expression.
                    header-name:
                        type: str
                        description: Deprecated, please rename it to header_name. HTTP header.
                    id:
                        type: int
                        description: ID.
            header-name:
                type: str
                description: Deprecated, please rename it to header_name. HTTP header.
            host:
                type: str
                description: Host address
            host-regex:
                type: str
                description: Deprecated, please rename it to host_regex. Host regular expression.
            method:
                type: list
                elements: str
                description: No description.
                choices:
                    - 'delete'
                    - 'get'
                    - 'head'
                    - 'options'
                    - 'post'
                    - 'put'
                    - 'trace'
                    - 'connect'
            name:
                type: str
                description: Address name.
                required: true
            path:
                type: str
                description: URL path regular expression.
            tags:
                type: str
                description: Applied object tags.
            type:
                type: str
                description: Address type.
                choices:
                    - 'host-regex'
                    - 'url'
                    - 'category'
                    - 'method'
                    - 'ua'
                    - 'header'
                    - 'src-advanced'
                    - 'dst-advanced'
            ua:
                type: list
                elements: str
                description: No description.
                choices:
                    - 'chrome'
                    - 'ms'
                    - 'firefox'
                    - 'safari'
                    - 'other'
            uuid:
                type: str
                description: Universally Unique IDentifier.
            visibility:
                type: str
                description: Enable/disable address visibility.
                choices:
                    - 'disable'
                    - 'enable'
'''

EXAMPLES = '''
- name: Example playbook (generated based on argument schema)
  hosts: fortimanagers
  connection: httpapi
  vars:
    ansible_httpapi_use_ssl: true
    ansible_httpapi_validate_certs: false
    ansible_httpapi_port: 443
  tasks:
    - name: Explicit web proxy address configuration.
      fortinet.fortimanager.fmgr_firewall_explicitproxyaddress:
        # bypass_validation: false
        workspace_locking_adom: <value in [global, custom adom including root]>
        workspace_locking_timeout: 300
        # rc_succeeded: [0, -2, -3, ...]
        # rc_failed: [-2, -3, ...]
        adom: <your own value>
        state: present # <value in [present, absent]>
        firewall_explicitproxyaddress:
          case_sensitivity: <value in [disable, enable]>
          category: <string>
          color: <integer>
          comment: <string>
          header: <string>
          header_group:
            -
              case_sensitivity: <value in [disable, enable]>
              header: <string>
              header_name: <string>
              id: <integer>
          header_name: <string>
          host: <string>
          host_regex: <string>
          method:
            - delete
            - get
            - head
            - options
            - post
            - put
            - trace
            - connect
          name: <string>
          path: <string>
          tags: <string>
          type: <value in [host-regex, url, category, ...]>
          ua:
            - chrome
            - ms
            - firefox
            - safari
            - other
          uuid: <string>
          visibility: <value in [disable, enable]>
'''

RETURN = '''
meta:
    description: The result of the request.
    type: dict
    returned: always
    contains:
        request_url:
            description: The full url requested.
            returned: always
            type: str
            sample: /sys/login/user
        response_code:
            description: The status of api request.
            returned: always
            type: int
            sample: 0
        response_data:
            description: The api response.
            type: list
            returned: always
        response_message:
            description: The descriptive message of the api response.
            type: str
            returned: always
            sample: OK.
        system_information:
            description: The information of the target system.
            type: dict
            returned: always
rc:
    description: The status the request.
    type: int
    returned: always
    sample: 0
version_check_warning:
    description: Warning if the parameters used in the playbook are not supported by the current FortiManager version.
    type: list
    returned: complex
'''
from ansible.module_utils.basic import AnsibleModule
from ansible.module_utils.connection import Connection
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec


def main():
    jrpc_urls = [
        '/pm/config/adom/{adom}/obj/firewall/explicit-proxy-address',
        '/pm/config/global/obj/firewall/explicit-proxy-address'
    ]

    perobject_jrpc_urls = [
        '/pm/config/adom/{adom}/obj/firewall/explicit-proxy-address/{explicit-proxy-address}',
        '/pm/config/global/obj/firewall/explicit-proxy-address/{explicit-proxy-address}'
    ]

    url_params = ['adom']
    module_primary_key = 'name'
    module_arg_spec = {
        'adom': {'required': True, 'type': 'str'},
        'firewall_explicitproxyaddress': {
            'type': 'dict',
            'v_range': [['6.2.0', '6.2.12']],
            'options': {
                'case-sensitivity': {'v_range': [['6.2.0', '6.2.12']], 'choices': ['disable', 'enable'], 'type': 'str'},
                'category': {'v_range': [['6.2.0', '6.2.12']], 'type': 'str'},
                'color': {'v_range': [['6.2.0', '6.2.12']], 'type': 'int'},
                'comment': {'v_range': [['6.2.0', '6.2.12']], 'type': 'str'},
                'header': {'v_range': [['6.2.0', '6.2.12']], 'type': 'str'},
                'header-group': {
                    'v_range': [['6.2.0', '6.2.12']],
                    'type': 'list',
                    'options': {
                        'case-sensitivity': {'v_range': [['6.2.0', '6.2.12']], 'choices': ['disable', 'enable'], 'type': 'str'},
                        'header': {'v_range': [['6.2.0', '6.2.12']], 'type': 'str'},
                        'header-name': {'v_range': [['6.2.0', '6.2.12']], 'type': 'str'},
                        'id': {'v_range': [['6.2.0', '6.2.12']], 'type': 'int'}
                    },
                    'elements': 'dict'
                },
                'header-name': {'v_range': [['6.2.0', '6.2.12']], 'type': 'str'},
                'host': {'v_range': [['6.2.0', '6.2.12']], 'type': 'str'},
                'host-regex': {'v_range': [['6.2.0', '6.2.12']], 'type': 'str'},
                'method': {
                    'v_range': [['6.2.0', '6.2.12']],
                    'type': 'list',
                    'choices': ['delete', 'get', 'head', 'options', 'post', 'put', 'trace', 'connect'],
                    'elements': 'str'
                },
                'name': {'v_range': [['6.2.0', '6.2.12']], 'required': True, 'type': 'str'},
                'path': {'v_range': [['6.2.0', '6.2.12']], 'type': 'str'},
                'tags': {'v_range': [['6.2.0', '6.2.12']], 'type': 'str'},
                'type': {
                    'v_range': [['6.2.0', '6.2.12']],
                    'choices': ['host-regex', 'url', 'category', 'method', 'ua', 'header', 'src-advanced', 'dst-advanced'],
                    'type': 'str'
                },
                'ua': {'v_range': [['6.2.0', '6.2.12']], 'type': 'list', 'choices': ['chrome', 'ms', 'firefox', 'safari', 'other'], 'elements': 'str'},
                'uuid': {'v_range': [['6.2.0', '6.2.12']], 'type': 'str'},
                'visibility': {'v_range': [['6.2.0', '6.2.12']], 'choices': ['disable', 'enable'], 'type': 'str'}
            }

        }
    }

    module_option_spec = get_module_arg_spec('full crud')
    module_arg_spec.update(module_option_spec)
    params_validation_blob = []
    check_galaxy_version(module_arg_spec)
    module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'firewall_explicitproxyaddress'),
                           supports_check_mode=False)

    if not module._socket_path:
        module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
    connection = Connection(module._socket_path)
    connection.set_option('access_token', module.params.get('access_token', None))
    connection.set_option('enable_log', module.params.get('enable_log', False))
    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
    fmgr.validate_parameters(params_validation_blob)
    fmgr.process_curd(argument_specs=module_arg_spec)

    module.exit_json(meta=module.params)


if __name__ == '__main__':
    main()

==> ansible-10.4.0.tgz: lib/python3.11/site-packages/ansible_collections/fortinet/fortimanager/plugins/modules/fmgr_firewall_explicitproxyaddress.py <==
#!/usr/bin/python
from __future__ import absolute_import, division, print_function
# Copyright 2019-2024 Fortinet, Inc.
# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

__metaclass__ = type

ANSIBLE_METADATA = {'status': ['preview'],
                    'supported_by': 'community',
                    'metadata_version': '1.1'}

DOCUMENTATION = '''
---
module: fmgr_firewall_explicitproxyaddress
short_description: Explicit web proxy address configuration.
description:
    - This module is able to configure a FortiManager device.
    - Examples include all parameters and values which need to be adjusted to data sources before usage.

version_added: "2.2.0"
author:
    - Xinwei Du (@dux-fortinet)
    - Xing Li (@lix-fortinet)
    - Jie Xue (@JieX19)
    - Link Zheng (@chillancezen)
    - Frank Shen (@fshen01)
    - Hongbin Lu (@fgtdev-hblu)
notes:
    - Starting in version 2.4.0, all input arguments are named using the underscore naming convention (snake_case).
      Please change the arguments such as "var-name" to "var_name".
      Old argument names are still available yet you will receive deprecation warnings.
      You can ignore this warning by setting deprecation_warnings=False in ansible.cfg.
    - Running in workspace locking mode is supported in this FortiManager module, the top
      level parameters workspace_locking_adom and workspace_locking_timeout help do the work.
    - To create or update an object, use state present directive.
    - To delete an object, use state absent directive.
    - Normally, running one module can fail when a non-zero rc is returned. you can also override
      the conditions to fail or succeed with parameters rc_failed and rc_succeeded
options:
    access_token:
        description: The token to access FortiManager without using username and password.
        type: str
    bypass_validation:
        description: Only set to True when module schema diffs with FortiManager API structure, module continues to execute without validating parameters.
        type: bool
        default: false
    enable_log:
        description: Enable/Disable logging for task.
        type: bool
        default: false
    forticloud_access_token:
        description: Authenticate Ansible client with forticloud API access token.
        type: str
    proposed_method:
        description: The overridden method for the underlying Json RPC request.
        type: str
        choices:
          - update
          - set
          - add
    rc_succeeded:
        description: The rc codes list with which the conditions to succeed will be overriden.
        type: list
        elements: int
    rc_failed:
        description: The rc codes list with which the conditions to fail will be overriden.
        type: list
        elements: int
    state:
        description: The directive to create, update or delete an object.
        type: str
        required: true
        choices:
          - present
          - absent
    workspace_locking_adom:
        description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
        type: str
    workspace_locking_timeout:
        description: The maximum time in seconds to wait for other user to release the workspace lock.
        type: int
        default: 300
    adom:
        description: The parameter (adom) in requested url.
        type: str
        required: true
    firewall_explicitproxyaddress:
        description: The top level parameters set.
        required: false
        type: dict
        suboptions:
            case-sensitivity:
                type: str
                description: Deprecated, please rename it to case_sensitivity. Case sensitivity in pattern.
                choices:
                    - 'disable'
                    - 'enable'
            category:
                type: str
                description: FortiGuard category ID.
            color:
                type: int
                description: GUI icon color.
            comment:
                type: str
                description: Comment.
            header:
                type: str
                description: HTTP header regular expression.
            header-group:
                type: list
                elements: dict
                description: Deprecated, please rename it to header_group. Header group.
                suboptions:
                    case-sensitivity:
                        type: str
                        description: Deprecated, please rename it to case_sensitivity. Case sensitivity in pattern.
                        choices:
                            - 'disable'
                            - 'enable'
                    header:
                        type: str
                        description: HTTP header regular expression.
                    header-name:
                        type: str
                        description: Deprecated, please rename it to header_name. HTTP header.
                    id:
                        type: int
                        description: ID.
            header-name:
                type: str
                description: Deprecated, please rename it to header_name. HTTP header.
            host:
                type: str
                description: Host address
            host-regex:
                type: str
                description: Deprecated, please rename it to host_regex. Host regular expression.
            method:
                type: list
                elements: str
                description: HTTP methods.
                choices:
                    - 'delete'
                    - 'get'
                    - 'head'
                    - 'options'
                    - 'post'
                    - 'put'
                    - 'trace'
                    - 'connect'
            name:
                type: str
                description: Address name.
                required: true
            path:
                type: str
                description: URL path regular expression.
            tags:
                type: str
                description: Applied object tags.
            type:
                type: str
                description: Address type.
                choices:
                    - 'host-regex'
                    - 'url'
                    - 'category'
                    - 'method'
                    - 'ua'
                    - 'header'
                    - 'src-advanced'
                    - 'dst-advanced'
            ua:
                type: list
                elements: str
                description: User agent.
                choices:
                    - 'chrome'
                    - 'ms'
                    - 'firefox'
                    - 'safari'
                    - 'other'
            uuid:
                type: str
                description: Universally Unique IDentifier.
            visibility:
                type: str
                description: Enable/disable address visibility.
                choices:
                    - 'disable'
                    - 'enable'
'''

EXAMPLES = '''
- name: Example playbook (generated based on argument schema)
  hosts: fortimanagers
  connection: httpapi
  vars:
    ansible_httpapi_use_ssl: true
    ansible_httpapi_validate_certs: false
    ansible_httpapi_port: 443
  tasks:
    - name: Explicit web proxy address configuration.
      fortinet.fortimanager.fmgr_firewall_explicitproxyaddress:
        # bypass_validation: false
        workspace_locking_adom: <value in [global, custom adom including root]>
        workspace_locking_timeout: 300
        # rc_succeeded: [0, -2, -3, ...]
        # rc_failed: [-2, -3, ...]
        adom: <your own value>
        state: present # <value in [present, absent]>
        firewall_explicitproxyaddress:
          case_sensitivity: <value in [disable, enable]>
          category: <string>
          color: <integer>
          comment: <string>
          header: <string>
          header_group:
            -
              case_sensitivity: <value in [disable, enable]>
              header: <string>
              header_name: <string>
              id: <integer>
          header_name: <string>
          host: <string>
          host_regex: <string>
          method:
            - delete
            - get
            - head
            - options
            - post
            - put
            - trace
            - connect
          name: <string>
          path: <string>
          tags: <string>
          type: <value in [host-regex, url, category, ...]>
          ua:
            - chrome
            - ms
            - firefox
            - safari
            - other
          uuid: <string>
          visibility: <value in [disable, enable]>
'''

RETURN = '''
meta:
    description: The result of the request.
    type: dict
    returned: always
    contains:
        request_url:
            description: The full url requested.
            returned: always
            type: str
            sample: /sys/login/user
        response_code:
            description: The status of api request.
            returned: always
            type: int
            sample: 0
        response_data:
            description: The api response.
            type: list
            returned: always
        response_message:
            description: The descriptive message of the api response.
            type: str
            returned: always
            sample: OK.
        system_information:
            description: The information of the target system.
            type: dict
            returned: always
rc:
    description: The status the request.
    type: int
    returned: always
    sample: 0
version_check_warning:
    description: Warning if the parameters used in the playbook are not supported by the current FortiManager version.
    type: list
    returned: complex
'''
from ansible.module_utils.basic import AnsibleModule
from ansible.module_utils.connection import Connection
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec


def main():
    jrpc_urls = [
        '/pm/config/adom/{adom}/obj/firewall/explicit-proxy-address',
        '/pm/config/global/obj/firewall/explicit-proxy-address'
    ]

    perobject_jrpc_urls = [
        '/pm/config/adom/{adom}/obj/firewall/explicit-proxy-address/{explicit-proxy-address}',
        '/pm/config/global/obj/firewall/explicit-proxy-address/{explicit-proxy-address}'
    ]

    url_params = ['adom']
    module_primary_key = 'name'
    module_arg_spec = {
        'adom': {'required': True, 'type': 'str'},
        'firewall_explicitproxyaddress': {
            'type': 'dict',
            'v_range': [['6.2.0', '6.2.12']],
            'options': {
                'case-sensitivity': {'v_range': [['6.2.0', '6.2.12']], 'choices': ['disable', 'enable'], 'type': 'str'},
                'category': {'v_range': [['6.2.0', '6.2.12']], 'type': 'str'},
                'color': {'v_range': [['6.2.0', '6.2.12']], 'type': 'int'},
                'comment': {'v_range': [['6.2.0', '6.2.12']], 'type': 'str'},
                'header': {'v_range': [['6.2.0', '6.2.12']], 'type': 'str'},
                'header-group': {
                    'v_range': [['6.2.0', '6.2.12']],
                    'type': 'list',
                    'options': {
                        'case-sensitivity': {'v_range': [['6.2.0', '6.2.12']], 'choices': ['disable', 'enable'], 'type': 'str'},
                        'header': {'v_range': [['6.2.0', '6.2.12']], 'type': 'str'},
                        'header-name': {'v_range': [['6.2.0', '6.2.12']], 'type': 'str'},
                        'id': {'v_range': [['6.2.0', '6.2.12']], 'type': 'int'}
                    },
                    'elements': 'dict'
                },
                'header-name': {'v_range': [['6.2.0', '6.2.12']], 'type': 'str'},
                'host': {'v_range': [['6.2.0', '6.2.12']], 'type': 'str'},
                'host-regex': {'v_range': [['6.2.0', '6.2.12']], 'type': 'str'},
                'method': {
                    'v_range': [['6.2.0', '6.2.12']],
                    'type': 'list',
                    'choices': ['delete', 'get', 'head', 'options', 'post', 'put', 'trace', 'connect'],
                    'elements': 'str'
                },
                'name': {'v_range': [['6.2.0', '6.2.12']], 'required': True, 'type': 'str'},
                'path': {'v_range': [['6.2.0', '6.2.12']], 'type': 'str'},
                'tags': {'v_range': [['6.2.0', '6.2.12']], 'type': 'str'},
                'type': {
                    'v_range': [['6.2.0', '6.2.12']],
                    'choices': ['host-regex', 'url', 'category', 'method', 'ua', 'header', 'src-advanced', 'dst-advanced'],
                    'type': 'str'
                },
                'ua': {'v_range': [['6.2.0', '6.2.12']], 'type': 'list', 'choices': ['chrome', 'ms', 'firefox', 'safari', 'other'], 'elements': 'str'},
                'uuid': {'v_range': [['6.2.0', '6.2.12']], 'type': 'str'},
                'visibility': {'v_range': [['6.2.0', '6.2.12']], 'choices': ['disable', 'enable'], 'type': 'str'}
            }

        }
    }

    module_option_spec = get_module_arg_spec('full crud')
    module_arg_spec.update(module_option_spec)
    params_validation_blob = []
    check_galaxy_version(module_arg_spec)
    module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'firewall_explicitproxyaddress'),
                           supports_check_mode=True)

    if not module._socket_path:
        module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
    connection = Connection(module._socket_path)
    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
    fmgr.validate_parameters(params_validation_blob)
    fmgr.process_curd(argument_specs=module_arg_spec)

    module.exit_json(meta=module.params)


if __name__ == '__main__':
    main()
